@@ -733,12 +733,16 @@ strvis(char *mbdst, const char *mbsrc, int flags)
  * NetBSD: 2012,  strnvis(char *dst, size_t dlen, const char *src, int flag);
  */
 int
+strnvis_openbsd(char *, const char *, size_t, int);
+int
 strnvis_openbsd(char *mbdst, const char *mbsrc, size_t dlen, int flags)
 {
 	return istrsenvisxl(mbdst, &dlen, mbsrc, flags, "", NULL);
 }
 libbsd_symver_default(strnvis, strnvis_openbsd, LIBBSD_0.2);
 
+int
+strnvis_netbsd(char *, size_t, const char *, int);
 int
 strnvis_netbsd(char *mbdst, size_t dlen, const char *mbsrc, int flags)
 {
